@@ -10,7 +10,7 @@ class H5Dataset(Dataset):
     """
     Basic datset class for handling h5 files. Do not call this class directly.
     """
-    def __init__(self, data_path: str, data_key: str, target_path: str, target_key: str, transform: Optional[Callable] = None):
+    def __init__(self, data_path: str, data_key: str, target_path: str, target_key: str, transform: Optional[Callable] = None, transform_target: Optional[Callable] = None):
         data_path = Path(data_path)
         target_path = Path(target_path)
 
@@ -20,6 +20,7 @@ class H5Dataset(Dataset):
         self.targets = np.squeeze(self.targets).tolist()
         self.classes = list(set(self.targets))
         self.transform = transform
+        self.transform_target = transform_target
 
     def __getitem__(self, index: int) -> Tuple[Any, Any]:
         """
@@ -35,6 +36,9 @@ class H5Dataset(Dataset):
         if self.transform is not None:
             sample = self.transform(sample)
 
+        if self.transform_target is not None:
+            target = self.transform_target(target)
+
         return sample, target
 
     def __len__(self) -> int:
